#pragma once

#include <vector>

#include "glm/glm.hpp"

typedef std::vector<float> Vector6;

class Orbit
{
public:
    Orbit(const Vector6 keplerianElements);
    ~Orbit() = default; 

    // TODO: meanAnomaly in all these arguments actually means eccentricMeanAnomaly,
    // will have to change that when adding non-ellipctical orbits - don't get confused!
    const glm::vec3 getPosition(const float meanAnomaly) const;
    glm::vec3 getTangent(const float meanAnomaly);
    glm::mat4 getLookAlongMatrix(const float meanAnomaly);

    void setElements(Vector6 keplerianElements);
    void getElements(Vector6& keplerianElements) const;

private:
    Vector6 _keplerianElements;

    const float getEccentricAnomaly(const float meanAnomaly) const;
    const float getTrueAnomaly(const float meanAnomaly) const;
    const Vector6 getCartesianCoordinates(const float meanAnomaly) const;
};
